.. image:: https://img.shields.io/pypi/v/scrunch.svg
   :target: https://pypi.org/project/scrunch

.. image:: https://img.shields.io/pypi/pyversions/scrunch.svg

.. image:: https://img.shields.io/travis/Crunch-io/scrunch/master.svg
   :target: https://travis-ci.org/Crunch-io/scrunch

.. .. image:: https://img.shields.io/appveyor/ci/jaraco/skeleton/master.svg
..    :target: https://ci.appveyor.com/project/jaraco/skeleton/branch/master

.. image:: https://readthedocs.org/projects/scrunch/badge/?version=latest
   :target: https://scrunch.readthedocs.io/en/latest/?badge=latest

Pythonic scripting library for cleaning data in `Crunch <http://crunch.io/>`__
==============================================================================

To learn more, including how to install the library, see the
`Overview <https://github.com/Crunch-io/scrunch/wiki/Overview>`__ wiki
page.

Once you have it installed, to get started using ``scrunch`` to work with data in Crunch, see the `User Guide <https://github.com/Crunch-io/scrunch/wiki/User-Reference>`__.
